from django.conf import settings
from django.conf.urls import patterns, include, url
from django.contrib import admin
from django.views.generic import RedirectView, TemplateView

from planeta import feeds, views

admin.autodiscover()


urlpatterns = patterns('',
    # Archive
    url(r'^(?P<year>\d{4})/$', views.YearArchiveView.as_view(), name='year-archive'),
    url(r'^(?P<year>\d{4})/(?P<month>[a-z]+)/$', views.MonthArchiveView.as_view(), name='month-archive'),
    url(r'^(?P<year>\d{4})/(?P<month>[a-z]+)/(?P<day>\d{2})/$', views.DayArchiveView.as_view(), name='day-archive'),
    url(r'^today/$', views.TodayView.as_view(), name='today'),

    # Feeds
    url(r'^feeds/$', views.FeedListView.as_view(), name='feed-list'),
    url(r'^feeds/(?P<pk>\d)/$', views.FeedDetailView.as_view(), name='feed-detail'),
    url(r'^feeds/(?P<feed_pk>\d+)/(?P<pk>\d+)$', views.EntryDetailView.as_view(), name='entry-detail'),

    # Syndication
    url(r'^rss/$', feeds.RSSFeed(), name='rss'),
    url(r'^atom/$', feeds.AtomFeed(), name='atom'),

    # Index, search...
    url(r'^$', views.IndexView.as_view(), name='index'),
    url(r'^search/', include('haystack.urls'), name='search'),
    url(r'^admin/', include(admin.site.urls)),
    url(r'^favicon.ico$', RedirectView.as_view(url=settings.STATIC_URL + 'favicon.ico')),
)

if settings.DEBUG:
    urlpatterns += patterns('',
        url(r'^media/(?P<path>.*)$', 'django.views.static.serve', {
            'document_root': settings.MEDIA_ROOT,
        }),
        url(r'^404/$', TemplateView.as_view(template_name='404.html')),
        url(r'^500/$', TemplateView.as_view(template_name='500.html')),
    )
